==> dde-launchpad_0.4.6.tar.xz: BUILD/translations/dde-launchpad_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="30"/>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="40"/>
        <source>Pin to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="49"/>
        <source>Remove from favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="49"/>
        <source>Add to favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="63"/>
        <source>Send to desktop</source>
        <translation>바탕화면으로 보내기</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="63"/>
        <source>Remove from desktop</source>
        <translation>바탕화면에서 제거</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="73"/>
        <source>Remove from dock</source>
        <translation>도구집에서 제거</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="73"/>
        <source>Send to dock</source>
        <translation>도구집으로 보내기</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="84"/>
        <source>Add to startup</source>
        <translation>시작에 추가하기</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="84"/>
        <source>Remove from startup</source>
        <translation>시작에서 제거하기</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="89"/>
        <source>Use a proxy</source>
        <translation>프록시 사용</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="95"/>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="102"/>
        <source>Uninstall</source>
        <translation>제거</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">인터넷</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">채팅</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">음악</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">동영상</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">그래픽</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">오피스</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">읽기</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">개발</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">시스템</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="19"/>
        <source>Internet</source>
        <translation type="unfinished">인터넷</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Chat</source>
        <translation type="unfinished">채팅</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Music</source>
        <translation type="unfinished">음악</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Video</source>
        <translation type="unfinished">동영상</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Graphics</source>
        <translation type="unfinished">그래픽</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Office</source>
        <translation type="unfinished">오피스</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Reading</source>
        <translation type="unfinished">읽기</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Development</source>
        <translation type="unfinished">개발</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>System</source>
        <translation type="unfinished">시스템</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="270"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="282"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="296"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="346"/>
        <location filename="../qml/WindowedFrame.qml" line="230"/>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="103"/>
        <source>Power</source>
        <translation>전원</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">설정</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="361"/>
        <location filename="../qml/WindowedFrame.qml" line="266"/>
        <source>Search</source>
        <translation>찾기</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="115"/>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="157"/>
        <source>My Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="191"/>
        <source>Add your favorite apps here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="202"/>
        <source>All Apps</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> dde-launchpad_0.6.12.tar.xz: BUILD/translations/dde-launchpad_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="31"/>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="41"/>
        <source>Pin to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Remove from favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Add to favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Send to desktop</source>
        <translation>바탕화면으로 보내기</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Remove from desktop</source>
        <translation>바탕화면에서 제거</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Remove from dock</source>
        <translation>도구집에서 제거</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Send to dock</source>
        <translation>도구집으로 보내기</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Add to startup</source>
        <translation>시작에 추가하기</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Remove from startup</source>
        <translation>시작에서 제거하기</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="92"/>
        <source>Use a proxy</source>
        <translation>프록시 사용</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="100"/>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="107"/>
        <source>Uninstall</source>
        <translation>제거</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">인터넷</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">채팅</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">음악</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">동영상</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">그래픽</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">오피스</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">읽기</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">개발</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">시스템</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="26"/>
        <source>Power</source>
        <translation type="unfinished">전원</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="40"/>
        <source>Search</source>
        <translation type="unfinished">찾기</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>Frequently Used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>All Apps</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Internet</source>
        <translation type="unfinished">인터넷</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Chat</source>
        <translation type="unfinished">채팅</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Music</source>
        <translation type="unfinished">음악</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Video</source>
        <translation type="unfinished">동영상</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Graphics</source>
        <translation type="unfinished">그래픽</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Office</source>
        <translation type="unfinished">오피스</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Reading</source>
        <translation type="unfinished">읽기</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>Development</source>
        <translation type="unfinished">개발</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>System</source>
        <translation type="unfinished">시스템</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="41"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="313"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="325"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="339"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="27"/>
        <source>Recently Installed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="26"/>
        <source>All Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="76"/>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="39"/>
        <source>Free sorting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="52"/>
        <source>Sort by category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="64"/>
        <source>Sort by name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="124"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="139"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="154"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="169"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="184"/>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Power</source>
        <translation type="vanished">전원</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">설정</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">찾기</translation>
    </message>
</context>
</TS>
